@@ -8,10 +8,16 @@ const TEXDOC: &str = "http://texcreate.mkproj.com/";
 macro_rules! import_temp {
     ($c:expr, $x: expr) => {
         create(&$c.Project.project_name, &None , $x);
-        $c.adjust(&format!(
+        match $c.adjust(&format!(
             "./{}/{}.tex",
             $c.Project.project_name, $c.Project.project_name
-        ));
+        )){
+            Ok(a) => a,
+            Err(e) => {
+                eprintln!("{}", e)
+            }
+        };
+
         $c.add_packages(&format!("./{}/structure.tex", $c.Project.project_name));
     };
 }
@@ -22,6 +28,7 @@ macro_rules! import_temp {
 )]
 /// All TexCreate Subcommands
 enum CLI {
+    /// Update TexCreate
     #[structopt(name = "update", about = "Updates to latest version")]
     Update,
     #[structopt(about = "Initialize a config.toml file")]
@@ -59,6 +66,7 @@ enum CLI {
 #[tokio::main]
 async fn main() {
     let cli = CLI::from_args();
+    // Match CLI subcommands 
     match cli {
         CLI::Doc => {
             println!("Opening {}", TEXDOC);
@@ -71,7 +79,10 @@ async fn main() {
                 .spawn()
                 .expect("Failed to install latest version");
         }
-        CLI::Init => Config::init(),
+        CLI::Init => {
+            println!("Creating config.toml...");
+            Config::init()
+        },
         CLI::Create {
             template,
             name,
@@ -101,6 +112,9 @@ async fn main() {
                 Template::Beamer => {
                     import_temp!(conf, "Beamer");
                 }
+                Template::Lachaise => {
+                    import_temp!(conf, "Lachaise");
+                }
                 Template::Book => mkcreate(
                     &conf.Project.project_name,
                     &conf.Project.title,
